@@ -5,25 +5,36 @@ from trytond.pool import Pool
 from . import stock
 from . import product
 
+from .stock import LotMixin
+
+__all__ = ['LotMixin', 'register']
+
 
 def register():
     Pool.register(
         stock.Lot,
         stock.LotByLocationContext,
-        stock.LotType,
+        stock.LotsByLocations,
+        stock.LotByWarehouseContext,
+        stock.Location,
         stock.Move,
+        stock.MoveAddLotsStart,
+        stock.MoveAddLotsStartLot,
         stock.ShipmentIn,
         stock.ShipmentOut,
         stock.ShipmentOutReturn,
+        stock.ShipmentInternal,
         stock.Period,
         stock.PeriodCacheLot,
         stock.Inventory,
         stock.InventoryLine,
         stock.InventoryCountSearch,
+        product.Configuration,
+        product.ConfigurationDefaultLotSequence,
         product.Template,
         product.Product,
-        product.TemplateLotType,
         module='stock_lot', type_='model')
     Pool.register(
+        stock.MoveAddLots,
         stock.InventoryCount,
         module='stock_lot', type_='wizard')
